@@ -1,7 +1,9 @@
 import asyncio
 import functools
+import inspect
 import logging
 import os
+from json import JSONDecodeError
 from random import randrange
 from time import sleep
 from typing import Any, Callable
@@ -9,7 +11,8 @@ from typing import Any, Callable
 import requests
 
 from eth_retry.conditional_imports import (HTTPError,  # type: ignore
-                                           OperationalError, ReadTimeout)
+                                           MaxRetryError, OperationalError,
+                                           ReadTimeout)
 
 logger = logging.getLogger('eth_retry')
 
@@ -26,11 +29,13 @@ def auto_retry(func: Callable[...,Any]) -> Callable[...,Any]:
     - HTTPError
     - asyncio.exceptions.TimeoutError
     - ReadTimeout
+    - JSONDecodeError
     
     It will also retry on specific ValueError exceptions:
     - Max rate limit reached
     - please use API Key for higher rate limit
     - execution aborted (timeout = 5s)
+    - parse error
     
     On repeat errors, will retry in increasing intervals.
     '''
@@ -60,7 +65,7 @@ def auto_retry(func: Callable[...,Any]) -> Callable[...,Any]:
             try:
                 return await func(*args,**kwargs)
             except asyncio.exceptions.TimeoutError:
-                logger.warning(f'asyncio timeout [{failures}]')
+                logger.warning(f'asyncio timeout [{failures}] {_get_caller_details_from_stack()}')
                 continue
             except Exception as e:
                 if not should_retry(e, failures):
@@ -84,6 +89,9 @@ def should_retry(e: Exception, failures: int) -> bool:
         # Occurs on any chain when making computationally intensive calls. Just retry.
         # Sometimes works, sometimes doesn't. Worth a shot.
         'execution aborted (timeout = 5s)',
+        'max retries exceeded with url',
+        'temporary failure in name resolution',
+        'parse error',
 
         # From block explorer while interacting with api. Just retry.
         'max rate limit reached',
@@ -94,6 +102,9 @@ def should_retry(e: Exception, failures: int) -> bool:
 
         # The standard Moralis rate limiting message. Just retry.
         'too many requests'
+      
+        # You get this ssl error in docker sometimes
+        'cannot assign requested address',
     )
     if any(err in str(e).lower() for err in retry_on_errs):
         return True
@@ -102,7 +113,9 @@ def should_retry(e: Exception, failures: int) -> bool:
         ConnectionError,
         requests.exceptions.ConnectionError,
         HTTPError,
-        ReadTimeout
+        ReadTimeout,
+        MaxRetryError,
+        JSONDecodeError,
     ]
     if any(isinstance(e, E) for E in general_exceptions) and 'Too Large' not in str(e) and '404' not in str(e):
         return True
@@ -111,3 +124,10 @@ def should_retry(e: Exception, failures: int) -> bool:
         return True
 
     return False
+
+
+def _get_caller_details_from_stack():
+    code_context = inspect.stack()[2].code_context
+    if code_context is None:
+        return f"{inspect.stack()[2].filename} line {inspect.stack()[2].lineno}"
+    return f"{inspect.stack()[2].filename} line {inspect.stack()[2].lineno} {[code_context[0].strip()]}"
